==> localnews-news-api-1.1.0-20181023.092125-2-sources.jar: com/bxm/localnews/news/controller/NewsReplyController.java <==
package com.bxm.localnews.news.controller;

import com.bxm.localnews.common.annotation.TouTiaoAuth;
import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.Json;
import com.bxm.localnews.common.vo.MPage;
import com.bxm.localnews.news.service.NewsReplyService;
import com.bxm.localnews.news.vo.MyReceiveReplysVO;
import com.bxm.localnews.news.vo.MyReplysVO;
import com.bxm.localnews.news.vo.NewsReply;
import com.bxm.localnews.news.vo.NewsReplyVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

@Api(tags = "4-03 新闻回复接口", description = "对应的评论信息")
@RequestMapping("/api")
@RestController
public class NewsReplyController {

    @Resource
    private NewsReplyService newsReplyService;

    @ApiOperation(value = "4-03-1 获取全部评论列表", notes = "", httpMethod = "GET")
    @ApiImplicitParam(name = "newsId", value = "新闻ID")
    @RequestMapping(value = "news/reply/list", method = RequestMethod.GET)
    public Json<List<NewsReplyVO>> getReplys(@RequestParam(value = "newsId") Long newsId, MPage page) {
        page.checkPage();
        List<NewsReplyVO> list = this.newsReplyService.queryReplyList(newsId, page);
        return ResultUtil.genSuccessResultWithPage(list, page);
    }

    @ApiOperation(value = "4-03-2 用户发表点评", notes = "", httpMethod = "POST")
    @TouTiaoAuth
    @RequestMapping(value = "news/reply", method = RequestMethod.POST)
    public Json reply(NewsReply newsReply) {
        return this.newsReplyService.reply(newsReply);
    }

    @ApiOperation(value = "4-03-3 我发表的评论列表", notes = "不包含已删除的评论", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户id", required = true),
            @ApiImplicitParam(name = "current", value = "current")
    })
    @RequestMapping(value = "news/myReply/list", method = RequestMethod.GET)
    public Json<List<MyReplysVO>> myReplys(@RequestParam(value = "userId") Long userId, MPage page,
                                           @RequestParam(value = "current", required = false) Integer current) {
        if (current == null) {
            current = 1;
        }
        page.setCurPage(current);
        page.checkPage();
        List<MyReplysVO> list = this.newsReplyService.selectMyReplys(userId, page);
        return ResultUtil.genSuccessResultWithPage(list, page);
    }

    @ApiOperation(value = "4-03-4 删除我的评论", notes = "", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "replyId", value = "回复id", required = true)
    })
    @RequestMapping(value = "news/del/myReply", method = RequestMethod.GET)
    public Json delMyReply(@RequestParam(value = "replyId") Long replyId) {
        return this.newsReplyService.delMyReply(replyId);
    }

    @ApiOperation(value = "4-03-5 我收到的评论列表", notes = "", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户id", required = true),
            @ApiImplicitParam(name = "current", value = "current")
    })
    @RequestMapping(value = "news/receiveReply/list", method = RequestMethod.GET)
    public Json<MyReceiveReplysVO> myReceiveReplys(@RequestParam(value = "userId") Long userId, MPage page,
                                                   @RequestParam(value = "current", required = false) Integer current) {
        if (current == null) {
            current = 1;
        }
        page.setCurPage(current);
        page.checkPage();
        List<MyReceiveReplysVO> list = this.newsReplyService.myReceiveReplys(userId, page);
        return ResultUtil.genSuccessResultWithPage(list, page);
    }

}

==> localnews-news-api-1.1.0-20181025.092318-3-sources.jar: com/bxm/localnews/news/controller/NewsReplyController.java <==
package com.bxm.localnews.news.controller;

import com.bxm.localnews.common.annotation.TouTiaoAuth;
import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.Json;
import com.bxm.localnews.common.vo.MPage;
import com.bxm.localnews.news.service.NewsReplyService;
import com.bxm.localnews.news.vo.MyReceiveReplysVO;
import com.bxm.localnews.news.vo.MyReplysVO;
import com.bxm.localnews.news.vo.NewsReply;
import com.bxm.localnews.news.vo.NewsReplyVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

@Api(tags = "4-03 新闻回复接口", description = "对应的评论信息")
@RequestMapping("/api")
@RestController
public class NewsReplyController {

    @Resource
    private NewsReplyService newsReplyService;

    @ApiOperation(value = "4-03-1 获取全部评论列表", notes = "", httpMethod = "GET")
    @ApiImplicitParam(name = "newsId", value = "新闻ID")
    @RequestMapping(value = "news/reply/list", method = RequestMethod.GET)
    public Json<List<NewsReplyVO>> getReplys(@RequestParam(value = "newsId") Long newsId, MPage page) {
        page.checkPage();
        List<NewsReplyVO> list = this.newsReplyService.queryReplyList(newsId, page);
        return ResultUtil.genSuccessResultWithPage(list, page);
    }

    @ApiOperation(value = "4-03-2 用户发表点评", notes = "", httpMethod = "POST")
    @TouTiaoAuth
    @RequestMapping(value = "news/reply", method = RequestMethod.POST)
    public Json reply(NewsReply newsReply) {
        return this.newsReplyService.reply(newsReply);
    }

    @ApiOperation(value = "4-03-3 我发表的评论列表", notes = "不包含已删除的评论", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户id", required = true),
            @ApiImplicitParam(name = "current", value = "current")
    })
    @RequestMapping(value = "news/myReply/list", method = RequestMethod.GET)
    public Json<List<MyReplysVO>> myReplys(@RequestParam(value = "userId") Long userId, MPage page,
                                           @RequestParam(value = "current", required = false) Integer current) {
        if (current == null) {
            current = 1;
        }
        page.setCurPage(current);
        page.checkPage();
        List<MyReplysVO> list = this.newsReplyService.selectMyReplys(userId, page);
        return ResultUtil.genSuccessResultWithPage(list, page);
    }

    @ApiOperation(value = "4-03-4 删除我的评论", notes = "", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "replyId", value = "回复id", required = true)
    })
    @RequestMapping(value = "news/del/myReply", method = RequestMethod.GET)
    public Json delMyReply(@RequestParam(value = "replyId") Long replyId) {
        return this.newsReplyService.delMyReply(replyId);
    }

    @ApiOperation(value = "4-03-5 我收到的评论列表", notes = "", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户id", required = true),
            @ApiImplicitParam(name = "current", value = "current")
    })
    @RequestMapping(value = "news/receiveReply/list", method = RequestMethod.GET)
    public Json<List<MyReceiveReplysVO>> myReceiveReplys(@RequestParam(value = "userId") Long userId, MPage page,
                                                         @RequestParam(value = "current", required = false) Integer current) {
        if (current == null) {
            current = 1;
        }
        page.setCurPage(current);
        page.checkPage();
        List<MyReceiveReplysVO> list = this.newsReplyService.myReceiveReplys(userId, page);
        return ResultUtil.genSuccessResultWithPage(list, page);
    }

}
